@@ -175,6 +175,19 @@ int glocal2_pair_wise (Alignment *A,int*ns, int **ls,Constraint_list *CL);
 int linked_pair_wise ( Alignment *A, int *ns, int **l_s, Constraint_list *CL);
 int linked_pair_wise_collapse ( Alignment *A, int *ns, int **l_s, Constraint_list *CL);
 int cl2pair_list_ecl_ext_pc ( Alignment *A, int *ns, int **ls, Constraint_list *CL, int ***list_in, int *n_in);
+int procoffee_pair_wise ( Alignment *A, int *nsi, int **lsi, Constraint_list *CL);
+
+
+/////////////////////////////////////////////////////////////////////////////////////////////////////////
+///////////////                                                                           ///////////////
+///////////////                                                                           ///////////////
+///////////////                       Profile_PW                                          ///////////////
+///////////////                                                                           ///////////////
+///////////////                                                                           ///////////////
+/////////////////////////////////////////////////////////////////////////////////////////////////////////
+
+int **aln2prf (Alignment *A, char *matrix);
+char *add_sequence2prf (char *seq, char *al,int **prf, int lj, int gop, int gep);
 void free_proba_pair_wise();
 
 int subop1_pair_wise ( Alignment *A, int *ns, int **ls, Constraint_list *CL);
@@ -270,6 +283,8 @@ Alignment * full_sorted_aln (Alignment *A, Constraint_list *CL);
 /*                                                                */
 /*                                                                */
 /******************************************************************/
+int *  set_profile_master (Alignment *A,int *ns, int **ls, Constraint_list *CL);
+int *unset_profile_master (Alignment *A,int *ns, int **ls, Constraint_list *CL);
 
 Constraint_list *profile2list     ( Job_TC *job,int nprf);
 Constraint_list *seq2list     (Job_TC *Job);
@@ -321,7 +336,8 @@ Constraint_list * rna_pair (TC_method *M , char *in_seq, Constraint_list *CL);
 Constraint_list *best_pair4prot (Job_TC *job);
 Constraint_list *best_pair4rna (Job_TC *job);
 Alignment * fast_pair      (Job_TC *job);
-			    
+Constraint_list *hash_pair (TC_method *M , char *in_seq, Constraint_list *CL);
+
 void toggle_case_in_align_two_sequences(int value);
 Alignment * align_two_sequences ( char *seq1, char *seq2, char *matrix, int gop, int gep, char *align_mode);
 Alignment * align_two_aln ( Alignment *A1, Alignment  *A2, char *in_matrix, int gop, int gep, char *in_align_mode);
@@ -368,16 +384,19 @@ int split_condition (int nseq, int score, Constraint_list *CL);
 
 int profile_pair_wise (Alignment *A, int n1, int *l1, int n2, int *l2, Constraint_list *CL);
 int pair_wise (Alignment *A, int*ns, int **l_s,Constraint_list *CL );
-
+int hh_pair_wise (Alignment *A, int *ns, int **ls, Constraint_list *CL);
+int co_pair_wise (Alignment *A, int *ns, int **ls, Constraint_list *CL);
 int empty_pair_wise ( Alignment *A, int *ns, int **l_s, Constraint_list *CL, int glocal);
 
 
 Pwfunc get_pair_wise_function (Pwfunc func, char *dp_mode, int *glocal);
 
 
-
+/*********************************************************************/
 char *build_consensus ( char *seq1, char *seq2, char *dp_mode);
 int fastal (int argv, char **arg);
+int tree_aln_N ( NT_node P, Sequence *S, int N, int argc, char **argv);
+
 
 int domain_pair_wise (Alignment *A,int*ns, int **l_s,Constraint_list *CL );
 Alignment *domain_match_list2aln ( Alignment *A,int *ns,int **l_s,int **ml, int nseq, int len);
@@ -815,7 +834,7 @@ Sequence *pavie_seq2noisy_seq (Sequence *S, int val,char *subst);
 /* Centro de Regulacio Genomica */
 /*and */
 /*Cedric Notredame */
-/*Fri Feb 18 08:27:45 CET 2011 - Revision 596. */
+/*2012-02-16 18:52:59. */
 /*All rights reserved.*/
 /*This file is part of T-COFFEE.*/
 /**/
