@@ -3,7 +3,7 @@
 #include <stdlib.h>
 #include <math.h>
 #include <stdarg.h>
-
+#include <string.h>
 
 #include "io_lib_header.h"
 #include "util_lib_header.h"
@@ -242,28 +242,11 @@ static int key;
   return NULL;
 }
   
-/* old declare_char_node (too hungry)
-Char_node * declare_char_node (int action)
-{
-  static int key;
-  Char_node *cn;
-  static Char_node *root;
-
-  if ( action==DECLARE)
-    {
-      cn=vcalloc (1, sizeof (Char_node));
-      cn->key=++key;
-      cn->c=vcalloc (256, sizeof (Char_node *));
-      
-      }
-  return cn;
-}
-*/			 
 /******************************COPYRIGHT NOTICE*******************************/
 /* Centro de Regulacio Genomica */
 /*and */
 /*Cedric Notredame */
-/*Fri Feb 18 08:27:45 CET 2011 - Revision 596. */
+/*2012-02-16 18:52:59. */
 /*All rights reserved.*/
 /*This file is part of T-COFFEE.*/
 /**/
