@@ -280,8 +280,29 @@ int ** read_matrice (char *mat_name_in)
 	l=strlen(AA);
 
 	
-
-
+	if ( strcmp (mat_name_in, "list")==0)
+	  {
+	    fprintf ( stderr, "****List of available matrices\n");
+	    fprintf ( stderr, "\tidmat\n");
+	    fprintf ( stderr, "\tmd_40mt\n");
+	    fprintf ( stderr, "\tmd_350mt\n");
+	    fprintf ( stderr, "\tmd_250mt\n");
+	    fprintf ( stderr, "\tpam120mt\n");
+	    fprintf ( stderr, "\tpam160mt\n");
+	    fprintf ( stderr, "\tpam350mt\n");
+	    
+	    fprintf ( stderr, "\tblosum30mt\n");
+	    fprintf ( stderr, "\tblosum40mt\n");
+	    fprintf ( stderr, "\tblosum45mt\n");
+	    fprintf ( stderr, "\tblosum50mt\n");
+	    fprintf ( stderr, "\tblosum55mt\n");
+	    fprintf ( stderr, "\tblosum62mt\n");
+	    fprintf ( stderr, "\tblosum80mt\n");
+	    myexit (EXIT_SUCCESS);
+	    
+	  }
+	    
+	    
 	if ( strm2 (mat_name_in, "pam", "PAM"))sprintf ( mat_name, "pam250mt");
 	else if (strm2 (mat_name_in, "blosum", "BLOSUM"))sprintf ( mat_name, "blosum62mt");
 	else if (strm3 (mat_name_in, "id", "ID", "idmat"))sprintf ( mat_name, "idmat");
@@ -755,7 +776,7 @@ FILE_format* (*vfclose_format)         ( FILE_format *))
 	}	
     if ( max_len>max_name_len)max_len=max_name_len;
     
-   sprintf (buf, "\n%s, %s(%s)\n%s\n",PROGRAM,VERSION,DATE, AUTHOR);     
+   sprintf (buf, "\n%s, %s (%s)\n%s\n",PROGRAM,VERSION,BUILD_INFO, AUTHOR);
    fps=print_format_string ( buf,white, ink, fps);
 
    if(B->output_tm == 1)
@@ -893,7 +914,7 @@ FILE_format* (*vfclose_format)         ( FILE_format *))
     
     
     
-    sprintf (buf, "%s, %s(%s)\n%s\nCPU TIME:%d sec.\n%s",PROGRAM,VERSION,DATE, AUTHOR,  (B->cpu+get_time())/1000, (S->generic_comment)?S->generic_comment:"");     
+    sprintf (buf, "%s, %s (%s)\n%s\nCPU TIME:%d sec.\n%s",PROGRAM,VERSION,BUILD_INFO, AUTHOR,  (B->cpu+get_time())/1000, (S->generic_comment)?S->generic_comment:"");
     fps=print_format_string ( buf,white, ink, fps);
     sprintf (buf, "SCORE=%d\n*\n", S->score_aln);
     fps=print_format_string ( buf,white, ink, fps);
@@ -1007,7 +1028,83 @@ FILE_format* (*vfclose_format)         ( FILE_format *))
 
     }
 
+int output_reliability_format_fasta ( Alignment *B,Alignment *S,char *name, \
+FILE_format *(*vfopen_format)          ( char *),\
+FILE_format *(*print_format_string)    ( char * ,Color *, Color *, FILE_format*),\
+FILE_format *(*print_format_char)      ( int    ,Color *, Color *, FILE_format*),\
+void         (*get_rgb_values_format)  ( int    ,Color *),\
+FILE_format* (*vfclose_format)         ( FILE_format *))
+    {
+    int a, b, c,l;
+    int max_name_len=15;
+    int max_len=0;
+    static char *buf,*buf2;
+    int s;
+    static FILE_format *fps;
+    Color *ink;
+    Color *box_c;
+    Color *white;
+    int *n_residues;
+   
 
+    box_c=vcalloc ( 1, sizeof (Color));    
+    get_rgb_values_format (DEFAULT_COLOR, (white=vcalloc ( 1, sizeof (Color))));	
+    get_rgb_values_format (INK_COLOR,     (ink  =vcalloc ( 1, sizeof (Color))));
+    
+    n_residues=vcalloc ( B->nseq+1, sizeof (int));
+    for ( a=0; a<B->nseq; a++)n_residues[a]=B->order[a][1];
+
+
+    fps=vfopen_format( name);      
+    if ( buf==NULL)
+	{
+	buf=vcalloc (10000, sizeof (int));
+	buf2=vcalloc (10000, sizeof (int));
+	}
+
+    if ( max_len==0)
+	{
+	for ( a=0; a< B->nseq; a++)
+	    {if ( strlen (B->name[a])>max_len)
+		max_len= strlen ( (B->name[a]));
+	    }
+	}
+
+    if ( vfopen_format==vfopen_ascii)
+      {
+	fps->line+= max_len;
+      }
+    else if ( max_len>max_name_len)max_len=max_name_len;
+   
+   fps->line-=max_len;
+   fps->line=fps->line-(fps->line%3);
+ 
+	   for (b=0; b<S->nseq; b++)
+	     {
+	     sprintf (buf,">%-*.*s \n",max_len+2,max_len,S->name[b]);
+	     fps=print_format_string ( buf,white, ink, fps);
+	     for (fps->in_seq=1,c=0;c<B->len_aln;c++)
+		{
+		   n_residues[b]+=!is_gap(B->seq_al[b][c]);
+		   s=B->seq_al[b][c];
+		   if (!is_gap(s) && S->seq_al[b][c]!=NO_COLOR_RESIDUE )
+			{
+			get_rgb_values_format ( S->seq_al[b][c], box_c);			    	
+			}
+		   else
+		        {
+			get_rgb_values_format (GAP_COLOR, box_c);
+			}
+		   
+		fps=print_format_char ( s,box_c, ink,fps);
+		}
+	      fps->in_seq=0;
+	      fps=print_format_char ( '\n', white, ink, fps);	      
+	     }
+    vfclose_format( fps);
+    return 1;
+    }
+    
 /*****************************************************************************/
 /*                       PDF         FUNCTIONS                               */
 /*                                                                           */
@@ -1422,6 +1519,12 @@ int       output_reliability_ascii     ( Alignment *B,Alignment *S, char *name)
       return 1;
       }
 
+int       output_reliability_fasta     ( Alignment *B,Alignment *S, char *name)
+      {
+      output_reliability_format_fasta (B, S, name, vfopen_ascii,print_ascii_string,print_ascii_char,get_rgb_values_ascii, vfclose_ascii);
+      return 1;
+      }
+      
 FILE_format *print_ascii_string( char *s, Color *box, Color *ink, FILE_format *fascii)
       {
       int l;
@@ -1505,7 +1608,7 @@ int       output_seq_reliability_ascii     ( Alignment *B,Alignment *S, char *na
 /* Centro de Regulacio Genomica */
 /*and */
 /*Cedric Notredame */
-/*Fri Feb 18 08:27:45 CET 2011 - Revision 596. */
+/*2012-02-16 18:52:59. */
 /*All rights reserved.*/
 /*This file is part of T-COFFEE.*/
 /**/
