@@ -25,20 +25,20 @@ Constraint_list *prepare_cl_for_moca ( Constraint_list *CL)
 		     CL->do_self=1;
 		     CL->get_dp_cost=moca_slow_get_dp_cost;
 		     CL->evaluate_residue_pair=moca_residue_pair_extended_list;
-		     
+
    /*Prepare the moca parameters*/
 		     (CL->moca)->evaluate_domain=evaluate_moca_domain;
 		     (CL->moca)->cache_cl_with_domain=cache_cl_with_moca_domain;
 		     (CL->moca)->make_nol_aln=make_moca_nol_aln;
-   
-   /*Prepare the packing of the sequences*/		     
+
+   /*Prepare the packing of the sequences*/
 		     for ( a=0, b=1; a< (CL->S)->nseq; a++)b+=strlen ( (CL->S)->seq[a])+1;
-			 
+
 		     seq =declare_char ( 1,b+1);
 		     name=declare_char(  1,30);
 		     CL->packed_seq_lu  =declare_int ( b, 2);
-		     
-		     
+
+
 		     for (tot_l=1,a=0; a< (CL->S)->nseq; a++)
 		       {
 			 strcat (seq[0], (CL->S)->seq[a]);
@@ -49,16 +49,16 @@ Constraint_list *prepare_cl_for_moca ( Constraint_list *CL)
 			     CL->packed_seq_lu[tot_l][0]=a;
 			     CL->packed_seq_lu[tot_l][1]=c;
 			   }
-			 CL->packed_seq_lu[tot_l++][0]=UNDEFINED; 
+			 CL->packed_seq_lu[tot_l++][0]=UNDEFINED;
 		       }
 		     sprintf ( name[0], "catseq");
-		     NS=fill_sequence_struc(1, seq, name); 
+		     NS=fill_sequence_struc(1, seq, name, NULL);
 		     CL->S=add_sequence (NS, CL->S, 0);
 		     free_char( seq, -1);
 		     free_char(name, -1);
 		     free_sequence (NS, NS->nseq);
-		     
-		     
+
+
     return CL;
    }
 
@@ -66,24 +66,24 @@ Alignment ** moca_aln ( Constraint_list *CL)
    {
      /*
        function documentation: start
-       
+
        Alignment ** moca_aln ( Constraint_list *CL)
-       
+
        This function inputs CL and outputs a series of local multiple alignments
        contained in aln_list;
-      
+
        The terminator of aln_list is set to NULL;
-       
+
        function documentation: end
      */
-       
-     
+
+
    static int max_n_domains=1000;
    int n_domains=0;
-   
+
    Alignment **aln_list;
-   
-   
+
+
 
    aln_list=vcalloc (max_n_domains, sizeof (Alignment *));
    if ((CL->moca)->moca_interactive)aln_list[n_domains++]=extract_domain ( CL);
@@ -101,24 +101,24 @@ Alignment ** moca_aln ( Constraint_list *CL)
      }
    return aln_list;
    }
-   
+
 Alignment * extract_domain ( Constraint_list *CL)
    {
      /*
        function documentation: start
        Alignment * extract_domain ( Constraint_list *CL)
-       
+
        given a CL, this function extracts the next best scoring local multiple alignment
        It returns a CL where the aligned residues have been indicated in (CL->moca)->forbiden_residues;
-       
+
        the local alignment is extracted with the dp function indicated by
                            CL->dp_mode: (gotoh_sw_pair_wise)
        Evaluation:
                   CL->get_dp_cost=slow_get_dp_cost;
 		  CL->evaluate_residue_pair=sw_residue_pair_extended_list;
        Continuation:
-                 (CL->moca)->evaluate_domain=evaluate_moca_domain;       
-       Cache of CL:		  
+                 (CL->moca)->evaluate_domain=evaluate_moca_domain;
+       Cache of CL:
                  (CL->moca)->cache_cl_with_domain=cache_cl_with_moca_domain;
        Domain post processing:
                  (CL->moca)->make_nol_aln=make_moca_nol_aln;
@@ -131,7 +131,7 @@ Alignment * extract_domain ( Constraint_list *CL)
      Alignment *EA=NULL;
 
 
-     
+
 
      /*CASE 1: Non Automatic Domain Extraction*/
      if ((CL->moca)->moca_interactive)
@@ -140,12 +140,12 @@ Alignment * extract_domain ( Constraint_list *CL)
 	 }
      else if ((CL->moca)->moca_len)
        {
-	 while ((C=extract_domain_with_coordinates (C,(CL->moca)->moca_start,(CL->moca)->moca_len,CL))->nseq==0)(CL->moca)->moca_scale=(CL->moca)->moca_scale*0.9;    
+	 while ((C=extract_domain_with_coordinates (C,(CL->moca)->moca_start,(CL->moca)->moca_len,CL))->nseq==0)(CL->moca)->moca_scale=(CL->moca)->moca_scale*0.9;
 	 RESULT=copy_aln ( C, RESULT);
 	 unpack_seq_aln (RESULT, CL);
 	 output_format_aln ("mocca_aln",RESULT,EA=fast_coffee_evaluate_output(RESULT, CL),"stdout");
 	 free_aln(EA);
-	
+
 	 return RESULT;
        }
      else if ( !(CL->moca)->moca_len)
@@ -155,8 +155,8 @@ Alignment * extract_domain ( Constraint_list *CL)
        }
 
      /*CASE 2: Automatic Domain Extraction: Find Coordinates*/
-          
-       
+
+
      start=500;
 
      step=10;
@@ -164,8 +164,8 @@ Alignment * extract_domain ( Constraint_list *CL)
      max_start=strlen ((CL->S)->seq[0]);
      min_len=20;
      max_len=strlen ((CL->S)->seq[0]);
-     
-     C=extract_domain_with_coordinates (C,13,30,CL);     
+
+     C=extract_domain_with_coordinates (C,13,30,CL);
      C->output_res_num=1;
      print_aln (C);
 
@@ -176,9 +176,9 @@ Alignment * extract_domain ( Constraint_list *CL)
      (CL->moca)->moca_scale=-160;
      C=add_seq2aln (CL,C, CL->S);
      print_aln (C);
-     
+
      myexit (EXIT_FAILURE);
-     
+
      while ( step>0)
        {
 	 C=approximate_domain (min_start,max_start,step,min_len,max_len, step,&start, &len, &score, CL);
@@ -188,7 +188,7 @@ Alignment * extract_domain ( Constraint_list *CL)
 	 max_len=len+step;
 	 step=step/2;
        }
-   
+
      C=extract_domain_with_coordinates (C,start-10, len+20,CL);
      C->output_res_num=1;
      print_aln (C);
@@ -216,13 +216,13 @@ Alignment * interactive_domain_extraction ( Constraint_list *CL)
      Alignment *PREVIOUS=NULL;
      Alignment *C=NULL;
      Alignment *EA=NULL;
-     
+
      int **parameters;
-     
-     
+
+
      choice=vcalloc ( 100, sizeof (char));
      parameters=declare_int (10000, 4);
-     
+
      parameters[0][START]=(CL->moca)->moca_start;
      parameters[0][LEN]=  (CL->moca)->moca_len;
      parameters[0][SCALE]=(CL->moca)->moca_scale;
@@ -230,17 +230,17 @@ Alignment * interactive_domain_extraction ( Constraint_list *CL)
      iteration=0;
      sprintf ( last_start, "%d", (CL->moca)->moca_start);
      sprintf ( out_format, "mocca_aln");
-     
+
      print_moca_interactive_choices ();
      while ( !strm4 (choice, "Q","X", "q", "x" ))
 	     {
 	       c=choice[0];
-	       
+
 	       if (c=='b' || c=='B')
 		 {
-		 iteration-=atoi(choice+1)+1;		   
-		   
-		 if (iteration<0)iteration=1;  
+		 iteration-=atoi(choice+1)+1;
+
+		 if (iteration<0)iteration=1;
 		 }
 	       else
 		 {
@@ -254,16 +254,16 @@ Alignment * interactive_domain_extraction ( Constraint_list *CL)
 		 else if ( c=='|')
 		   {
 		   sprintf ( last_start, "%s", choice);
-		   parameters[iteration][START]=0;  
+		   parameters[iteration][START]=0;
 		   s=strrchr(choice, ':');
-		   
+
 		   if (s==NULL)
 		     {
 		       parameters[iteration][START]=atoi(choice+1);
 		     }
 		   else
 		     {
-		      
+
 		       s[0]='\0';
 
 		       if((index=name_is_in_list (choice+1,(CL->S)->name,(CL->S)->nseq,100))==-1)
@@ -278,7 +278,7 @@ Alignment * interactive_domain_extraction ( Constraint_list *CL)
 		       }
 		     parameters[iteration][START]+=atoi(s+1)-1;
 		     }
-		       
+
 		   }
 		 else if ( c=='C'||c=='c')parameters[iteration][SCALE]=atoi(choice+1);
 		 else if ( c=='G'||c=='g')
@@ -292,7 +292,7 @@ Alignment * interactive_domain_extraction ( Constraint_list *CL)
 		   }
 		 else if ( c=='S'||c=='s')
 		   {
-		     if (choice[1]=='\0')sprintf ( choice, "default.domain_aln.%d", iteration); 
+		     if (choice[1]=='\0')sprintf ( choice, "default.domain_aln.%d", iteration);
 		     output_format_aln (out_format,RESULT,EA=fast_coffee_evaluate_output(RESULT, CL),choice+1);
 		     fprintf (stderr, "\tOutput  file [%15s] in [%10s] format\n",choice+1,out_format);
 		     free_aln (EA);
@@ -304,18 +304,18 @@ Alignment * interactive_domain_extraction ( Constraint_list *CL)
 			 fprintf ( stderr, "\nWARNING: THRESHOLD RESET to 0");
 			 parameters[iteration][SCALE]=0;
 		       }
-		     
+
 		     (CL->moca)->moca_scale=parameters[iteration][SCALE];
 		      CL->gop=parameters[iteration][GOPP];
 
 		     C=extract_domain_with_coordinates (C,parameters[iteration][START],parameters[iteration][LEN],CL);
-		     
+
 		     if ( C==NULL)
 		       {
 			 fprintf ( stderr, "\nERROR: ILLEGAL COORDINATES! SEQUENCE BOUNDARY CROSSED\n");
 			 for ( b=1,a=0; a< (CL->S)->nseq-1; a++)
 			   {
-			     
+
 			     fprintf ( stderr, "\n\t%15s=> Abs:[%d %d] Rel:[0 %d]", (CL->S)->name[a],b, b+(CL->S)->len[a]-1,(CL->S)->len[a]);
 			     b+=(CL->S)->len[a];
 			   }
@@ -336,16 +336,16 @@ Alignment * interactive_domain_extraction ( Constraint_list *CL)
 			 RESULT=copy_aln ( C, RESULT);
 			 unpack_seq_aln (RESULT, CL);
 			 RESULT->output_res_num=1;
-			 
+
 			 output_format_aln (out_format,RESULT,EA=fast_coffee_evaluate_output(RESULT, CL),"stdout");
 			 free_aln(EA);
 			 PREVIOUS=copy_aln ( RESULT, PREVIOUS);
 			 free_aln (C);
 			 print_moca_interactive_choices ();
-			
+
 		       }
 		   }
-		
+
 		 fprintf ( stderr, "\t[ITERATION %3d][START=%s][LEN=%3d][GOPP=%3d][SCALE=%4d]\t",iteration,last_start,parameters[iteration][LEN],parameters[iteration][GOPP],parameters[iteration][SCALE]);
 		 a=0;
 		 fprintf ( stderr, "Your Choice: ");
@@ -353,7 +353,7 @@ Alignment * interactive_domain_extraction ( Constraint_list *CL)
 		 choice[a]=0;
 		 }
 	     }
-     
+
      if (!RESULT)myexit(EXIT_SUCCESS);
      if ( RESULT)RESULT->output_res_num=0;
      return RESULT;
@@ -385,26 +385,26 @@ return 0;
 }
 
 Alignment * approximate_domain ( int min_start, int max_start, int step_start,int min_len, int max_len, int step_len, int *best_start, int *best_len, int *best_score, Constraint_list *CL)
-   {    
+   {
      Alignment *C=NULL;
      int start;
      int len;
      int score;
-         
+
      /*1 Extract the first*/
      best_score[0]=UNDEFINED;
      best_start[0]=min_start;
      best_len[0]=min_len;
-     
+
      for (start=min_start; start< max_start; start+=step_start)
        {
 	 for ( len=min_len; len<max_len; len+=step_len)
 	   {
 	     C=extract_domain_with_coordinates (C,start,len,CL);
 	     if ( C==NULL)continue;
-	     score=((CL->moca)->evaluate_domain)(C, CL); 
+	     score=((CL->moca)->evaluate_domain)(C, CL);
 	     fprintf ( stderr, "\nSTART=%d LEN=%3d SCORE=%5d [%d]",start,len,score, C->nseq);
-	     
+
 
 	     if ( best_score[0]==UNDEFINED)best_score[0]=score;
 	     if ( score>best_score[0])
@@ -412,10 +412,10 @@ Alignment * approximate_domain ( int min_start, int max_start, int step_start,in
 		 best_score[0]=score;
 		 best_start[0]=start;
 		 best_len[0]=len;
-	       }	     
+	       }
 	   }
        }
-    
+
      C=extract_domain_with_coordinates (C,best_start[0], best_len[0],CL);
      C->output_res_num=1;
      return C;
@@ -429,25 +429,25 @@ int measure_domain_length ( Constraint_list *CL,Alignment *IN, int start, int mi
 
    score_matrix=vcalloc ( max_len, sizeof (int));
    len_matrix=vcalloc ( max_len, sizeof (int));
-   
-   
+
+
    l=strlen ( (CL->S)->seq[0]);
-   
+
    min_len=MAX(0, min_len);
    min_len=MIN(l-start, min_len);
-   
+
    if ( !IN)C=extract_domain_with_coordinates (C,start,min_len, CL);
-   else 
+   else
      {
      C=copy_aln (IN, C);
      C->len_aln=min_len;
      for ( a=0; a< C->nseq; a++)C->seq_al[a][min_len]='\0';
      C=add_seq2aln (CL,C, CL->S);
      }
-   
+
   best_score= score=((CL->moca)->evaluate_domain)(C, CL);
-  
-  
+
+
   min_len=MAX(0, min_len);
   for ( best_len=best_val=n_val=0,b=min_len; b<max_len && (start+b)<l; b+=step, n_val++)
        {
@@ -461,7 +461,7 @@ int measure_domain_length ( Constraint_list *CL,Alignment *IN, int start, int mi
 	   }
        if ( C->len_aln>0 )score=((CL->moca)->evaluate_domain)(C, CL);
        else score=-1;
-       
+
        if ( score< -3000)break;
 
        fprintf ( stderr, "\n\t%d %d=>%d (%d, %d)[%d]",start, b, score, C->nseq, C->len_aln, step);
@@ -483,7 +483,7 @@ int measure_domain_length ( Constraint_list *CL,Alignment *IN, int start, int mi
      }
    vfree ( score_matrix);
    vfree ( len_matrix);
-   
+
    return best_len;
    }
 
@@ -492,10 +492,10 @@ Alignment *extract_domain_with_coordinates ( Alignment *RESULT,int start, int le
   int a;
   char *buf;
   Alignment *SEQ_DOMAIN=NULL;
-  
 
- 
-  
+
+
+
 
   /*ADJUST THE DIRECTION OF THE DOMAIN: len<0:left and len>0:right*/
 
@@ -507,8 +507,8 @@ Alignment *extract_domain_with_coordinates ( Alignment *RESULT,int start, int le
     }
 
   /*CHECK THAT THE BOUNDARY CONDITIONS*/
-  
- 
+
+
   if (start<0 || (!CL->packed_seq_lu && (start+len)>strlen((CL->S)->seq[0])) ||(CL->packed_seq_lu && (start+len)>strlen((CL->S)->seq[(CL->S)->nseq-1])) )return NULL;
   else
     {
@@ -521,9 +521,9 @@ Alignment *extract_domain_with_coordinates ( Alignment *RESULT,int start, int le
 	    }
 	}
     }
- 
+
   /*EXTRACT THE DOMAIN*/
-  
+
   SEQ_DOMAIN=add_seq2aln (CL,SEQ_DOMAIN, CL->S);
   buf=extract_char (SEQ_DOMAIN->seq_al[0], start, len);
 
@@ -532,8 +532,8 @@ Alignment *extract_domain_with_coordinates ( Alignment *RESULT,int start, int le
   SEQ_DOMAIN->order[0][1]=start;
   SEQ_DOMAIN=add_seq2aln (CL,SEQ_DOMAIN, CL->S);
 
- 
-  
+
+
   return SEQ_DOMAIN;
 }
 
@@ -543,45 +543,45 @@ Alignment *extract_domain_with_coordinates ( Alignment *RESULT,int start, int le
 int get_starting_point ( Constraint_list *CL)
 {
   int a;
-  
-  
+
+
   int l;
- 
- 
-  
- 
- 
+
+
+
+
+
   int **seq;
   int start;
   int *entry=NULL;
-  
+
   l=strlen ( (CL->S)->seq[0]);
-  
+
   seq=declare_int ( l, 2);
-  
-  
-  
+
+
+
    while (entry=extract_entry (CL))
      {
        seq[entry[R1]][1]=entry[R1];
        seq[entry[R2]][1]=entry[R2];
-       if ((CL->moca) && (CL->moca)->forbiden_residues && ((CL->moca)->forbiden_residues[0][entry[R1]]==UNDEFINED||(CL->moca)->forbiden_residues[0][entry[R2]]==UNDEFINED ))continue; 
+       if ((CL->moca) && (CL->moca)->forbiden_residues && ((CL->moca)->forbiden_residues[0][entry[R1]]==UNDEFINED||(CL->moca)->forbiden_residues[0][entry[R2]]==UNDEFINED ))continue;
        else
 	 {
 	   seq[entry[R1]][0]+=entry[MISC];
 	   seq[entry[R2]][0]+=entry[MISC];
 	 }
      }
-   
+
    sort_int_inv ( seq, 2, 0, 0, l-1);
    fprintf ( stderr, "\nStart=%d %d", seq[0][1], seq[0][0]);
    start=seq[0][1];
-   
-   
+
+
    free_int ( seq, -1);
    return start;
-   
-   
+
+
 }
 
 
@@ -593,7 +593,7 @@ int * analyse_sequence ( Constraint_list *CL)
  int best_tw, best_start=0, best_len=0;
  int l;
  int max_len=200;
- 
+
 
  l=strlen (( CL->S)->seq[0]);
 
@@ -606,17 +606,17 @@ int * analyse_sequence ( Constraint_list *CL)
 	for (tw=0, p=0; p<len; p++)
 	  {
 	    n_dots=CL->residue_index[0][p+start+1][0];
-	    
+
 	    for ( a=1; a<n_dots; a+=ICHUNK)
 	      {
-		
+
 		r=CL->residue_index[0][p+start+1][a+R2];
 		w=CL->residue_index[0][p+start+1][a+WE];
 
 		if (r<left || r>right)tw+=w;
 	      }
 	  }
-	
+
 	if ( tw> best_tw || best_tw==UNDEFINED)
 	  {
 	    best_tw=tw;
@@ -628,7 +628,7 @@ int * analyse_sequence ( Constraint_list *CL)
   fprintf ( stderr, "\nStart=%d Len=%d", best_start, best_len);
   return NULL;
 }
-			  
+
 /*********************************COPYRIGHT NOTICE**********************************/
 /* Centre National de la Recherche Scientifique (CNRS) */
 /*and */
@@ -654,7 +654,7 @@ int * analyse_sequence ( Constraint_list *CL)
 /* Centro de Regulacio Genomica */
 /*and */
 /*Cedric Notredame */
-/*Fri Feb 18 08:27:45 CET 2011 - Revision 596. */
+/*2012-02-16 18:52:59. */
 /*All rights reserved.*/
 /*This file is part of T-COFFEE.*/
 /**/
