@@ -3,6 +3,7 @@
 #include <math.h>
 #include <stdarg.h>
 #include <string.h>
+#include <limits.h>
 
 #include "io_lib_header.h"
 #include "util_lib_header.h"
@@ -31,9 +32,16 @@
       n[0]++;								\
     }									\
   
-int cl2pair_list_ecl ( Alignment *A, int *ns, int **ls, Constraint_list *CL, int ***list_in, int *n_in);
-
+ 
 
+void debug_list (char *tag, int n, int **list, int ex);
+void debug_list (char *tag, int n, int **list, int ex)
+{
+  int a;
+  for (a=0; a<n; a++)
+    fprintf (stdout, "\n_%s_: %d %d %d %d\n", tag,list[a][0], list[a][1],list[a][2],list[a][4]);
+  if (ex) exit(0);
+}
 
 /*******************************************************************************/
 /*                idscore_pairseq: measure the % id without delivering thze aln*/                                                   
@@ -451,10 +459,12 @@ int ** aln2local_penalties (Alignment *A, int n, int *ls, Constraint_list *CL, i
       gc=lg[close][p];
      
     
-      lg[GOP][p]=0.5*(1-(go/nn))*gop;
-      lg[GCP][p]=0.5*(1-(gc/nn))*gop;
-      //Checked locacal gep => gives low quality results
-      lg[GEP][p]=gep;//(1-((float)lg[gap][p]/(float)n))*gep;
+      lg[GOP][p]=0.1*(1-(go/nn))*gop;
+      lg[GCP][p]=0.1*(1-(gc/nn))*gop;
+      
+      lg[GEP][p]=gep;//NO LOCAL GEP
+      //(1-((float)lg[gap][p]/(float)n))*gep;//LOCAL_GEP
+      
       lg[open][p]=lg[close][p]=lg[gap][p]=0;
       
     }
@@ -691,7 +701,7 @@ int glocal2_pair_wise (Alignment *IN,int*ns, int **ls,Constraint_list *CL)
   
   gotoh_pair_wise_sw (A, ns, ls, CL);
   
-  HERE ("1");
+
   for (a=0; a<2; a++)
     {
       for (b=0; b<ns[a]; b++)
@@ -1380,6 +1390,110 @@ int cl2list_borders  (Alignment *A, int *ns, int **ls, Constraint_list *CL, int
   return read_array_size (list_in[0], sizeof (int*));
 }
 
+int cl2diag_cap_r390 (Alignment *A, int *ns, int **ls, Constraint_list *CL, int ***list_in, int *n_in)
+{
+  int **list;
+  int n, in, a, b, al1, al2;
+  int max_n;
+  int cap=0;
+  
+  if (!A) return 0;
+  
+  al1=strlen (A->seq_al[ls[0][0]]);
+  al2=strlen (A->seq_al[ls[1][0]]);
+  
+  list=list_in[0];
+  n=n_in[0];
+  max_n=read_array_size (list, sizeof (int*));
+  
+  
+  
+  
+  for (a=0; a< n; a++)
+    {
+      b=list[a][3];
+      list[a][3]=list[a][0];
+      list[a][0]=b;
+      
+    }
+  sort_list_int (list, 4, 1, 0, n-1);
+  for (a=0; a< n; a++)
+    {
+      b=list[a][3];
+      list[a][3]=list[a][0];
+      list[a][0]=b;
+    }
+  
+
+  in=n;
+  
+  for (a=0; a<in; a++)
+    {
+      int i, j, pi, pj, ni, nj;
+      if (list[a][2]==0)continue;
+      i=list[a][0];
+      j=list[a][1];
+      
+      if (a==0){pi=-10;pj=-10;}
+      else {pi=list[a-1][0];pj=list[a-1][1];}
+      
+      if (a==in-1){ni=-10; nj=-10;}
+      else {ni=list[a+1][0]; nj=list[a+1][1];}
+      
+      
+      if (i==0 || j==0);
+      else if ( i==pi || j==pj);
+      else if ( i-pi!=1 || j-pj!=1)
+	{
+	  
+	  
+	  int x;
+	  int delta=MAX((i-pi),(j-pj));
+	  for (x=1; x<=delta; x++)
+	    {
+	      if (n==max_n){max_n+=1000;list=vrealloc (list, max_n*sizeof (int*));}
+	      if (!list[n])list[n]=vcalloc (7, sizeof (int));
+	      if ((i-x)<=1)continue;
+	      if ((j-x)<=1)continue;
+	      list[n][0]=i-x;
+	      list[n][1]=j-x;
+	      list[n][3]=list[a][3];
+	      list[n][2]=cap;
+	      n++;
+	    }
+	}
+    
+    
+      if (i==al1 || j==al2);
+      else if ( i==ni || j==nj);
+      else if ( ni-i!=1 || nj-j!=1)
+	{
+	  int x;
+	  int delta=MAX((ni-i),(nj-j));
+	  for (x=1; x<=delta; x++)
+	    {
+		if (n==max_n){max_n+=1000;list=vrealloc (list, max_n*sizeof (int*));}
+		if (!list[n])list[n]=vcalloc (7, sizeof (int));
+		
+		if (i+x>=al1)continue;
+		if (j+x>=al2) continue;
+		
+		
+		list[n][0]=i+x;
+		list[n][1]=j+x;
+		list[n][3]=list[a][3];
+		list[n][2]=cap;
+		n++;
+	      }
+	  
+	}
+    
+    }
+  list_in[0]=list;
+  n_in[0]=n;
+  return n;
+}
+
 int cl2diag_cap (Alignment *A, int *nns, int **ls, Constraint_list *CL, int ***list, int *n)
 {
   int *sortseq;
@@ -1491,8 +1605,7 @@ int cl2diag_cap (Alignment *A, int *nns, int **ls, Constraint_list *CL, int ***l
   
   return n[0];
 }
-	  
-int cl2pair_list_ecl_pc ( Alignment *A, int *ns, int **ls, Constraint_list *CL, int ***list_in, int *n_in);
+int cl2pair_list_ext ( Alignment *A, int *ns, int **ls, Constraint_list *CL, int ***list_in, int *n_in);	  
 
 /**
  * Calculates scores for diagonal segments.
@@ -1504,21 +1617,46 @@ int cl2pair_list_ecl_pc ( Alignment *A, int *ns, int **ls, Constraint_list *CL,
  * \param list_in the diagonals
  * \param n_in number of sequences?
  */
-int fork_cl2pair_list_ecl_pc ( Alignment *A, int *ns, int **ls, Constraint_list *CL, int ***list_in, int *n_in);
-int nfork_cl2pair_list_ecl_pc ( Alignment *A, int *ns, int **ls, Constraint_list *CL, int ***list_in, int *n_in);
-int cl2pair_list_ecl_pc ( Alignment *A, int *ns, int **ls, Constraint_list *CL, int ***list_in, int *n_in)
+
+int fork_cl2pair_list_ext ( Alignment *A, int *ns, int **ls, Constraint_list *CL, int ***list_in, int *n_in, int njobs);
+int cl2pair_list_ext ( Alignment *A, int *ins, int **ils, Constraint_list *CL, int ***list_in, int *n_in)
 {
+  int *ns;
+  int **ls;
+  int ret;
+  int njobs;
   
   if (!CL || !CL->S || !CL->residue_index) return 0;
   
+  if (read_size_int(ins,sizeof (int))==3 && ins[2]!=-1)
+    {
+      ns=vcalloc (2, sizeof (int));
+      ls=declare_int (2,1);
+      ns[0]=ns[1]=1;
+      ls[0][0]=ils[0][ins[0]];
+      ls[1][0]=ils[1][ins[1]];
+    }
+  else
+    {
+      ns=ins;
+      ls=ils;
+    }
   
-  if ( get_nproc()==1)return  nfork_cl2pair_list_ecl_pc(A,ns,ls,CL,list_in,n_in);
-  else if (strstr ( CL->multi_thread, "pairwise"))return fork_cl2pair_list_ecl_pc(A,ns,ls,CL,list_in,n_in);
-  else return nfork_cl2pair_list_ecl_pc(A,ns,ls,CL,list_in,n_in);
+  if (strstr ( CL->multi_thread, "pairwise"))njobs=get_nproc();
+  else njobs=1;
+  
+  ret=fork_cl2pair_list_ext(A,ns,ls,CL,list_in,n_in,njobs);
+    
+  if (read_size_int (ins, sizeof(int))==3)
+    {
+      vfree (ns);
+      free_int (ls,-1);
+    }
+  return ret;
 }
+  
 
-
-int fork_cl2pair_list_ecl_pc ( Alignment *A, int *ns, int **ls, Constraint_list *CL, int ***list_in, int *n_in)
+int fork_cl2pair_list_ext ( Alignment *A, int *ns, int **ls, Constraint_list *CL, int ***list_in, int *n_in,int njobs)
 {
   int p1, p2,diag, si, s, r, t_s, t_r,t_w, t_s2, t_r2, t_w2;
   int a, b, l1, l2;
@@ -1537,13 +1675,12 @@ int fork_cl2pair_list_ecl_pc ( Alignment *A, int *ns, int **ls, Constraint_list
   //variables for fork
   FILE *fp;
   char **pid_tmpfile;
-  int sjobs, njobs,j;
+  int sjobs,j;
   int **sl;
-  
- 
+   
   if ( !A) return 0;
   
-  
+
   
   pos=aln2pos_simple ( A,-1, ns, ls);
   inv_pos=vcalloc ((CL->S)->nseq, sizeof (int*));
@@ -1558,7 +1695,7 @@ int fork_cl2pair_list_ecl_pc ( Alignment *A, int *ns, int **ls, Constraint_list
   for (a=0;a<ns[1]; a++)sl2[ls[1][a]]=1;
   norm=vcalloc ( l1+1, sizeof (float));
   
-  njobs=get_nproc();
+   
   sl=n2splits (njobs,l1+1);
   pid_tmpfile=vcalloc (njobs, sizeof (char*));
 
@@ -1658,117 +1795,6 @@ int fork_cl2pair_list_ecl_pc ( Alignment *A, int *ns, int **ls, Constraint_list
 
 
 
-
-int nfork_cl2pair_list_ecl_pc ( Alignment *A, int *ns, int **ls, Constraint_list *CL, int ***list_in, int *n_in)
-{
-  int p1, p2, si, s, r, t_s, t_r,t_w, t_s2, t_r2, t_w2;
-  int a, b, l1, l2;
-  int **pos;
-
-  int nused;
-  int *used_list;
-  int *sl2,*sl1, **inv_pos;
-
-
-  float nscore, score, tot, filter, avg=0, new=0;
-  float **used;
-  float *norm;
-
-  if ( !A) return 0;
-  
-  pos=aln2pos_simple ( A,-1, ns, ls);
-  inv_pos=vcalloc ((CL->S)->nseq, sizeof (int*));
-  for (a=0; a<ns[1]; a++)inv_pos[ls[1][a]] =seq2inv_pos(A->seq_al[ls[1][a]]);
-
-  l1=strlen (A->seq_al[ls[0][0]]);
-  l2=strlen (A->seq_al[ls[1][0]]);
-  sl1=vcalloc ((CL->S)->nseq, sizeof (int));
-  sl2=vcalloc ((CL->S)->nseq, sizeof (int));
-  
-  norm=vcalloc ( l1+1, sizeof (float));
-  
-
-  for (a=0;a<ns[0]; a++)sl1[ls[0][a]]=1;
-  for (a=0;a<ns[1]; a++)sl2[ls[1][a]]=1;
-  
-  
-
-  used=declare_float (l2+1,2);
-  used_list=vcalloc (l2+1, sizeof (int));
-  nused=0;
-
-  for (p1=0; p1<=l1; p1++)
-    {
-
-      for (tot=0,nused=0,si=0;p1>0 && si<ns[0]; si++)
-        {
-          s=ls [0][si];r=pos[s][p1-1];
-          for (a=1; r>0 && a<CL->residue_index[s][r][0];a+=ICHUNK)
-            {
-              t_s=CL->residue_index[s][r][a+SEQ2];
-              t_r=CL->residue_index[s][r][a+R2];
-              t_w=CL->residue_index[s][r][a+WE];
-	      if (sl1[t_s])continue;//do not extend within a profile
-	      
-	      norm[p1]++;
-              for (b=0; b<CL->residue_index[t_s][t_r][0];)
-                {
-                  if (b==0){t_s2=t_s;t_r2=t_r;t_w2=t_w;b++;}
-                  else
-                    {
-                      t_s2=CL->residue_index[t_s][t_r][b+SEQ2];
-                      t_r2=CL->residue_index[t_s][t_r][b+R2];
-                      t_w2=CL->residue_index[t_s][t_r][b+WE];
-                      b+=ICHUNK;
-                    }
-
-                  if (sl2[t_s2])
-                    {
-                      p2=inv_pos[t_s2][t_r2];
-		      score=MIN(((float)t_w/(float)NORM_F),((float)t_w2/(float)NORM_F));
-		      
-                      if (!used[p2][1] && score>0)
-                        {
-                          used_list[nused++]=p2;
-                        }
-
-                      tot+=score;
-                      used[p2][0]+=score;
-                      used[p2][1]++;
-                    }
-                }
-            }
-        }
-      //FILTER: Keep in the graph the edges where (p1->p2/(Sum (P1->x))>0.01
-      filter=0.01;
-      
-      for (a=0; a<nused; a++)
-        {
-
-          p2=used_list[a];
-          nscore=used[p2][0]/tot; //Normalized score used for filtering
-          score =used[p2][0];
-	  used[p2][0]=used[p2][1]=0;
-         
-          if (nscore>filter && p1!=0 && p2!=0 && p1!=l1 && p2!=l2)
-            {
-	      score=((norm[p1]>0)?score/norm[p1]:0)*NORM_F;
-	      addE (p1,p2,((l1-(p1))+(p2)),score,list_in, n_in);
-	    }
-	}
-    }
-  free_float (used, -1);
-  vfree (used_list);
-  free_int (inv_pos, -1);
-  free_int (pos, -1);
-  vfree (sl2);vfree (sl1);
-  vfree(norm);
-  return n_in[0];
-}
-
-
-
-
 int list2linked_pair_wise ( Alignment *A, int *ns, int **l_s, Constraint_list *CL, int **list, int n, char ***al, int *len);
 int linked_pair_wise ( Alignment *A, int *ns, int **ls, Constraint_list *CL)
 {
@@ -1820,7 +1846,7 @@ int linked_pair_wise ( Alignment *A, int *ns, int **ls, Constraint_list *CL)
   /*Prepare the list*/
   
   
-  cl2pair_list_ecl_pc (A, ns, ls, CL, &list, &n);
+  cl2pair_list_ext    (A, ns, ls, CL, &list, &n);
   cl2diag_cap         (A, ns, ls, CL, &list, &n);
   cl2list_borders     (A, ns, ls, CL, &list, &n);
   list2nodup_list     (A, ns, ls, CL, &list, &n);
@@ -1875,6 +1901,8 @@ int list2linked_pair_wise( Alignment *A, int *ns, int **l_s, Constraint_list *CL
   long score;
   int nomatch;
  
+
+  
   l1=strlen (A->seq_al[l_s[0][0]]);
   l2=strlen (A->seq_al[l_s[1][0]]);
   al=declare_char (2,l1+l2+1);
@@ -2155,17 +2183,17 @@ int linked_pair_wise_collapse ( Alignment *A, int *ns, int **ls, Constraint_list
     
   /*Prepare the list*/
   
-
   cl2pair_list_collapse (A, ns, ls, CL, &list, &n);
-  
   cl2diag_cap     (A, ns, ls, CL, &list, &n);
   cl2list_borders (A, ns, ls, CL, &list, &n);
   list2nodup_list (A, ns, ls, CL, &list, &n);
 
   /*Do the DP*/
+  
   score=list2linked_pair_wise (A, ns, ls, CL, list, n, &al,&len);
   CL=collapse_list (A,ns, ls, al, len, CL);
   free_char (al, -1);
+    
   /*Free the list*/
   return score;
 }
@@ -2382,11 +2410,274 @@ int ns2s (int *ns, int **ls, int *is1, int *is2, int *is)
   return s;
 }
 
+/////////////////////////////////////////////////////////////////////////////////////////////////////////
+///////////////                                                                           ///////////////
+///////////////                                                                           ///////////////
+///////////////                       OLD linked Pw                                       ///////////////
+///////////////                                                                           ///////////////
+///////////////                                                                           ///////////////
+/////////////////////////////////////////////////////////////////////////////////////////////////////////
+
+
+int cl2pair_list390 ( Alignment *A, int *ns, int **ls, Constraint_list *CL, int ***list_in, int *n_in);
+int cl2list_borders390   (Alignment *A, int *ns, int **ls, Constraint_list *CL, int ***list_in, int *n_in);
+int cl2diag_cap390 (Alignment *A, int *ns, int **ls, Constraint_list *CL, int ***list_in, int *n_in);
+int list2nodup_list390 ( Alignment *A, int *ns, int **ls, Constraint_list *CL, int ***list_in, int *n_in);
+int list2linked_pair_wise390( Alignment *A, int *ns, int **l_s, Constraint_list *CL, int **list, int n);
+
+void sort_list_int2_390 ( int **V,int *list,int N_F, int left, int right);
+int cmp_list_int2_390 (const int**a, const int**b);
+int cmp_list_int390 (const int**a, const int**b);
+void sort_list_int390 ( int **V,int N_F, int F, int left, int right);
+void sort_int390 ( int **V,int N_F, int F, int left, int right);
+void qsort390(void *base, size_t nmemb, size_t size, int (*compar)(const void *, const void *));
+
+int procoffee_pair_wise ( Alignment *A, int *nsi, int **lsi, Constraint_list *CL)
+{
+  int n=0;
+  int **list=NULL;
+  int score, a;
+  int *ns, **ls;
+  char **al;
+  int len=0;
+  if ( !CL->residue_index)return myers_miller_pair_wise (A, nsi,lsi,CL);
+  
+
+  ns=vcalloc (2, sizeof (int));
+  ns[0]=nsi[1]; ns[1]=nsi[0];
+  
+  
+  ls=declare_int (2, ns[0]+ns[1]);
+  for (a=0; a<ns[1]; a++)
+    ls[1][a]=lsi[0][a];
+  for (a=0; a<ns[0]; a++)
+    ls[0][a]=lsi[1][a];
+  
+  cl2list_borders(A, ns, ls, CL, &list, &n);
+  cl2pair_list_ext    (A, ns, ls, CL, &list, &n);
+  
+  cl2diag_cap390    (A, ns, ls, CL, &list, &n);
+
+  sort_list_int     (list,7, 1, 0, n-1);
+  list2nodup_list (A, ns, ls, CL, &list, &n);
+  score=list2linked_pair_wise (A, ns, ls, CL, list, n, &al,&len);
+  free_int (list,-1);
+  return score;
+}
+
+int cl2diag_cap390 (Alignment *A, int *ns, int **ls, Constraint_list *CL, int ***list_in, int *n_in)
+{
+  int **list;
+  int n, in, a, b, al1, al2;
+  int max_n;
+  int cap=0;
+  
+  if (!A) return 0;
+  
+  al1=strlen (A->seq_al[ls[0][0]]);
+  al2=strlen (A->seq_al[ls[1][0]]);
+  
+  list=list_in[0];
+  n=n_in[0];
+  max_n=read_array_size (list, sizeof (int*));
+  
+  
+  
+  
+  for (a=0; a< n; a++)
+    {
+      b=list[a][3];
+      list[a][3]=list[a][0];
+      list[a][0]=b;
+      
+    }
+  sort_list_int (list, 4, 1, 0, n-1);
+  for (a=0; a< n; a++)
+    {
+      b=list[a][3];
+      list[a][3]=list[a][0];
+      list[a][0]=b;
+    }
+  
+
+  in=n;
+  
+  for (a=0; a<in; a++)
+    {
+      int i, j, pi, pj, ni, nj;
+      if (list[a][2]==0)continue;
+      i=list[a][0];
+      j=list[a][1];
+      
+      if (a==0){pi=-10;pj=-10;}
+      else {pi=list[a-1][0];pj=list[a-1][1];}
+      
+      if (a==in-1){ni=-10; nj=-10;}
+      else {ni=list[a+1][0]; nj=list[a+1][1];}
+      
+      
+      if (i==0 || j==0);
+      else if ( i==pi || j==pj);
+      else if ( i-pi!=1 || j-pj!=1)
+	{
+	  
+	  
+	  int x;
+	  int delta=MAX((i-pi),(j-pj));
+	  for (x=1; x<=delta; x++)
+	    {
+	      if (n==max_n){max_n+=1000;list=vrealloc (list, max_n*sizeof (int*));}
+	      if (!list[n])list[n]=vcalloc (7, sizeof (int));
+	      if ((i-x)<=1)continue;
+	      if ((j-x)<=1)continue;
+	      list[n][0]=i-x;
+	      list[n][1]=j-x;
+	      list[n][3]=list[a][3];
+	      list[n][2]=cap;
+	      n++;
+	    }
+	}
+    
+    
+      if (i==al1 || j==al2);
+      else if ( i==ni || j==nj);
+      else if ( ni-i!=1 || nj-j!=1)
+	{
+	  int x;
+	  int delta=MAX((ni-i),(nj-j));
+	  for (x=1; x<=delta; x++)
+	    {
+		if (n==max_n){max_n+=1000;list=vrealloc (list, max_n*sizeof (int*));}
+		if (!list[n])list[n]=vcalloc (7, sizeof (int));
+		
+		if (i+x>=al1)continue;
+		if (j+x>=al2) continue;
+		
+		
+		list[n][0]=i+x;
+		list[n][1]=j+x;
+		list[n][3]=list[a][3];
+		list[n][2]=cap;
+		n++;
+	      }
+	  
+	}
+    
+    }
+  list_in[0]=list;
+  n_in[0]=n;
+  return n;
+}
+
+/////////////////////////////////////////////////////////////////////////////////////////////////////////
+///////////////                                                                           ///////////////
+///////////////                                                                           ///////////////
+///////////////                       Profile_PW                                          ///////////////
+///////////////                                                                           ///////////////
+///////////////                                                                           ///////////////
+/////////////////////////////////////////////////////////////////////////////////////////////////////////
+
+int **aln2prf (Alignment *A, char *matrix)
+{
+  int **mat=read_matrice (matrix);
+  int *vector;
+  int **prf;
+  int r,a,b,c;
+  vector=vcalloc (27, sizeof (int));
+  prf=declare_int (A->len_aln, 26);
+  
+  for (a=0; a<A->len_aln; a++)
+    {
+      for (b=0; b<26; b++)vector[b]=0;
+      for ( b=0; b<A->nseq; b++)
+	{
+	  r=tolower(A->seq_al[b][a]);
+	  if (r=='-')continue;
+	  r-='a';
+	  vector[r]++;
+	}
+      
+      for (b=0; b<26; b++)
+	{
+	  double score=0;
+	  double tot=0;
+	  for (c=0; c<26; c++)
+	    {
+	      
+	      score+=mat[b][c]*vector[c];
+	      tot  +=vector[c];
+	    }
+	  prf[a][b]=(int)((score/tot)*100);
+	}
+    }
+  vfree (vector);
+  
+  return prf;
+}
+char *add_sequence2prf (char *seq,char *al, int **prf, int lj, int gop, int gep)
+{
+  static int **match, **score,**indel,**tb;
+  int m,g;
+  int li, i, j,l;
+  static int max_i;
+  static int max_j;
+  gop*=100;
+  gep*=100;
+  if (seq)li=strlen (seq);
+  
+  if (li>max_i ||lj>max_j|| !seq)
+    {
+      if (match)free_int (match, -1);
+      if (score)free_int (score, -1);
+      if (indel)free_int (indel, -1);
+      if (!seq) return NULL;
+      
+      match=declare_int( li+1, lj+1);
+      score=declare_int( li+1, lj+1);
+      indel=declare_int( li+1, lj+1);
+      tb=declare_int( li+1, lj+1);
+      
+      max_i=li;
+      max_j=lj;
+    }
+  
+  if (!al)al=vcalloc ( li+lj+1, sizeof (char));
+  lower_string (seq);
+  for (i=1; i<=li; i++)//seq
+    {
+      match[i][0]=2*gop;
+      indel[i][0]=gop;
+      for (j=1; j<=lj; j++)//prf
+	{
+	  g=indel[i][j]=MAX((match[i][j-1]+gop),(indel[i][j-1]+gep));
+	  
+	  m=match[i][j]=score[i-1][j-1]+prf[j-1][seq[i-1]-'a'];
+	  if (m>g){score[i][j]=m;tb[i][j]=1;}
+	  else    {score[i][j]=g;tb[i][j]=0;}
+	}
+    }
+  
+  l=0;
+  i=li;
+  j=lj;
+  while (l<lj)
+    {
+
+      //HERE ("%d %d -- %d",i,j, tb[i][j]);
+      if (tb[i][j]==1){al[l]=seq[i-1];i--;j--;}
+      else {j--;al[l]='-';}
+      l++;
+    }
+  al[l]='\0';
+  
+  invert_string2 (al);
+  return al;
+}
 /******************************COPYRIGHT NOTICE*******************************/
 /* Centro de Regulacio Genomica */
 /*and */
 /*Cedric Notredame */
-/*Fri Feb 18 08:27:45 CET 2011 - Revision 596. */
+/*2012-02-16 18:52:59. */
 /*All rights reserved.*/
 /*This file is part of T-COFFEE.*/
 /**/
