@@ -51,7 +51,12 @@ static float RNAemitPairsDefault[6][6] = {
   { 0.0000375308f, 0.0000815823f, 0.0000824765f, 0.0000743985f, 0.0000743985f, 0.0000263252f }
 };
 
-//Protein Alignment Models
+//Protein Alignment Gap Model: Monophasic
+float initDistrib1Default[] = { 0.6080327034f, 0.1959836632f, 0.1959836632f };
+float gapOpen1Default[] = { 0.01993141696f, 0.01993141696f };
+float gapExtend1Default[] = { 0.7943345308f, 0.7943345308f };
+
+//Protein Alignment Models: bi-phasic
 static float initDistrib2Default[] = { 0.6814756989f, 8.615339902e-05f, 8.615339902e-05f, 0.1591759622f, 0.1591759622 };
 static float gapOpen2Default[] = { 0.0119511066f, 0.0119511066f, 0.008008334786f, 0.008008334786 };
 static float gapExtend2Default[] = { 0.3965826333f, 0.3965826333f, 0.8988758326f, 0.8988758326 };
@@ -596,7 +601,7 @@ int *** backward_so_dp_biphasic ( Alignment *A, int *ns, int **ls, int **pos0, i
 }
 
 
-int get_tot_prob (Alignment *A1,Alignment *A2, int *ns, int **ls, int nstates, float **matchProb, float **insProb, float *TmatchProb, float ***TinsProb, Constraint_list *CL);
+int get_tot_prob (Alignment *A1,Alignment *A2, int *ns, int **ls, int nstates, float **matchProb, float **insProb, float *TmatchProb, float ***TinsProb, Constraint_list *CL,int mode);
 
 float * forward_proba_pair_wise  ( char *seq1, char *seq2, int NumMatrixTypes, int NumInsertStates, float **transMat, float *initialDistribution,float *TmatchProb, float ***TinsProb, float **transProb);
 float * backward_proba_pair_wise ( char *seq1, char *seq2, int NumMatrixTypes, int NumInsertStates, float **transMat, float *initialDistribution,float *TmatchProb, float ***TinsProb,float **transProb);
@@ -624,7 +629,6 @@ int proba_pair_wise ( Alignment *A, int *ns, int **ls, Constraint_list *CL)
    char *alphabet;
   
    
-   
    //Free all the memory
    if (A==NULL)
      {
@@ -781,7 +785,11 @@ int proba_pair_wise ( Alignment *A, int *ns, int **ls, Constraint_list *CL)
        static float *s;
        NumInsertStates=2;
        NumMatrixTypes=5;
-       
+       if (atoigetenv ("NOBIPHASIC"))
+	 {
+	   NumInsertStates=1;
+	   NumMatrixTypes=3;
+	 }
        if (!p)
 	 {
 	   int l,a,b;
@@ -840,8 +848,10 @@ int proba_pair_wise ( Alignment *A, int *ns, int **ls, Constraint_list *CL)
        insProb=declare_float (256,NumMatrixTypes);
        matchProb=declare_float (256, 256);
        initialDistribution=vcalloc (2*NumMatrixTypes+1, sizeof (float));
-       
-       ProbabilisticModel (NumMatrixTypes,NumInsertStates,initDistrib2Default, emitSingle,emitPairs,gapOpen2Default,gapExtend2Default, transMat,initialDistribution,matchProb, insProb,transProb);
+       if (atoigetenv ("NOBIPHASIC"))
+	 ProbabilisticModel (NumMatrixTypes,NumInsertStates,initDistrib1Default, emitSingle,emitPairs,gapOpen1Default,gapExtend1Default, transMat,initialDistribution,matchProb, insProb,transProb);
+       else
+	 ProbabilisticModel (NumMatrixTypes,NumInsertStates,initDistrib2Default, emitSingle,emitPairs,gapOpen2Default,gapExtend2Default, transMat,initialDistribution,matchProb, insProb,transProb);
      }
    
    I=strlen (A->seq_al[ls[0][0]]);
@@ -864,8 +874,8 @@ int proba_pair_wise ( Alignment *A, int *ns, int **ls, Constraint_list *CL)
        TinsProb=declare_arrayN (3, sizeof (float),2,NumMatrixTypes,TinsProb_ml);
      }
    
-   get_tot_prob (A,A, ns,ls,NumMatrixTypes, matchProb, insProb,TmatchProb,TinsProb, CL);
-
+   get_tot_prob (A,A, ns,ls,NumMatrixTypes, matchProb, insProb,TmatchProb,TinsProb, CL, SEQUENCE);
+   
    F=forward_proba_pair_wise (A->seq_al[ls[0][0]], A->seq_al[ls[1][0]], NumMatrixTypes,NumInsertStates,transMat, initialDistribution,TmatchProb,TinsProb, transProb);
    B=backward_proba_pair_wise (A->seq_al[ls[0][0]], A->seq_al[ls[1][0]], NumMatrixTypes,NumInsertStates,transMat, initialDistribution,TmatchProb,TinsProb, transProb);
    A->CL=ProbaMatrix2CL(A,ns, ls,NumMatrixTypes,NumInsertStates, F, B, thr,CL);
@@ -874,7 +884,7 @@ int proba_pair_wise ( Alignment *A, int *ns, int **ls, Constraint_list *CL)
    return 1;
    }
 
-int get_tot_prob (Alignment *A1,Alignment *A2, int *ns, int **ls, int nstates, float **matchProb, float **insProb, float *TmatchProb, float ***TinsProb, Constraint_list *CL)
+int get_tot_prob (Alignment *A1,Alignment *A2, int *ns, int **ls, int nstates, float **matchProb, float **insProb, float *TmatchProb, float ***TinsProb, Constraint_list *CL, int mode)
 {
   int i, j, a, b, c,d, k, n,n1,n2, ij;
   int  c1, c2;
@@ -883,12 +893,12 @@ int get_tot_prob (Alignment *A1,Alignment *A2, int *ns, int **ls, int nstates, f
   char *ss1=NULL;
   char *ss2=NULL;
   int uss=0;
-  
+  static int gtp=0;
   //Pre-computation of the pairwise scores in order to use potential profiles
   //The profiles are vectorized AND Compressed so that the actual alphabet size (proteins/DNA) does not need to be considered
   
   
-  if (ns[0]==1 && ns[1]==1 )
+  if (mode==SEQUENCE)
     {
       int s1, s2;
       int *nns, **nls;
@@ -908,6 +918,7 @@ int get_tot_prob (Alignment *A1,Alignment *A2, int *ns, int **ls, int nstates, f
       sst1=seq2T_template_string((CL->S),s1);
       sst2=seq2T_template_string((CL->S),s2);
       
+      
       if (NA1 || NA2)
 	{
 	  if (NA1)
@@ -927,7 +938,7 @@ int get_tot_prob (Alignment *A1,Alignment *A2, int *ns, int **ls, int nstates, f
 	    for (a=0; a<ns[0]; a++)
 	      nls[0][a]=ls[0][a];
 	    }
-	  
+
 	  if (NA2)
 	    {
 	      nns[1]=NA2->nseq;
@@ -946,7 +957,7 @@ int get_tot_prob (Alignment *A1,Alignment *A2, int *ns, int **ls, int nstates, f
 	      nls[1][a]=ls[1][a];
 	    }
 	  
-	  get_tot_prob (NA1, NA2, nns, nls, nstates, matchProb, insProb, TmatchProb, TinsProb, CL);
+	  get_tot_prob (NA1, NA2, nns, nls, nstates, matchProb, insProb, TmatchProb, TinsProb, CL,PROFILE);
 	  vfree (nns); free_int (nls,-1);
 	  return 1;
 	}
@@ -1453,6 +1464,7 @@ int viterbi_pair_wise ( Alignment *A, int *ns, int **ls, Constraint_list *CL)
   seq1Length=I=strlen (A->seq_al[ls[0][0]]);
   seq2Length=J=strlen (A->seq_al[ls[1][0]]);
 
+  
   if (!transMat)
     {
        alphabet=alphabetDefault;
@@ -1502,7 +1514,7 @@ int viterbi_pair_wise ( Alignment *A, int *ns, int **ls, Constraint_list *CL)
 
    TmatchProb=vcalloc ((I+1)*(J+1), sizeof (float));
    TinsProb=declare_arrayN (3, sizeof (float),2,NumMatrixTypes,MAX(I,J)+1);
-   get_tot_prob (A,A, ns,ls,NumMatrixTypes, matchProb, insProb,TmatchProb,TinsProb, CL);
+   get_tot_prob (A,A, ns,ls,NumMatrixTypes, matchProb, insProb,TmatchProb,TinsProb, CL,SEQUENCE);
    
    // create viterbi matrix
    l=NumMatrixTypes * (seq1Length+1) * (seq2Length+1);
@@ -1698,7 +1710,7 @@ float ** get_emitPairs (char *mat, char *alp, float **p, float *s)
 /* Centro de Regulacio Genomica */
 /*and */
 /*Cedric Notredame */
-/*Fri Feb 18 08:27:45 CET 2011 - Revision 596. */
+/*2012-02-16 18:52:59. */
 /*All rights reserved.*/
 /*This file is part of T-COFFEE.*/
 /**/
