@@ -2,6 +2,7 @@
 #include <stdlib.h>
 #include <math.h>
 #include <stdarg.h>
+#include <string.h>
 
 #include "io_lib_header.h"
 #include "util_lib_header.h"
@@ -23,7 +24,51 @@ static int 	*tkill;
  *	\file util_make_tree.c
  *	\brief Source code tree algorithms
  */
-
+static int nred;
+NT_node Rredundate (NT_node T, Sequence* S, char *seq);
+NT_node redundate (Sequence* S,NT_node T, char *seq, char *tree)
+{
+  int a;
+  FILE *fp;
+  
+  nred=0;
+  printf_file (seq, "w", "");
+  for (a=0; a<S->nseq; a++)printf_file (seq, "a", ">%s\n%s\n", S->name [a], S->seq[a]);
+  Rredundate (T, S, seq);
+  
+  print_newick_tree (T,tree);
+}
+NT_node Rredundate (NT_node T, Sequence* S, char *seq)
+{
+  
+  if (!T) return NULL;
+  else if (T->isseq)
+    {
+      NT_node L, R;
+      L=new_declare_tree_node ();
+      R=new_declare_tree_node ();
+      T->right=R;
+      T->left=L;
+      R->parent=L->parent=T;
+      T->isseq=0;
+      
+      R->isseq=L->isseq=1;
+      sprintf (L->name, "NR_%d",++nred);
+      sprintf (R->name, "%s", T->name);
+      
+      printf_file (seq, "a", ">NR_%d\n%s\n", nred,S->seq[rand()%S->nseq]);
+    }
+  else
+    {
+      Rredundate (T->left ,S,seq);
+      Rredundate (T->right,S,seq);
+    }
+  return T;
+}
+      
+      
+	
+ 
 NT_node ** seq2cw_tree ( Sequence *S, char *tree)
 {
   Alignment *A;
@@ -59,7 +104,7 @@ NT_node ** make_upgma_tree (  Alignment *A,int **distances,int gop, int gep, cha
   }
 NT_node ** make_nj_tree (  Alignment *A,int **distances,int gop, int gep, char **out_seq, char **out_seq_name, int out_nseq, char *tree_file, char *tree_mode)
   {
-
+   
     if ( distances==NULL && A==NULL)
       {
 	fprintf ( stderr, "\nError: make_nj_tree, must provide an alignment or a distance matrix [FATAL:%s]", PROGRAM);
@@ -81,8 +126,9 @@ NT_node ** int_dist2nj_tree (int **distances, char **out_seq_name, int out_nseq,
 	  d=declare_double( out_nseq, out_nseq);
 	  for ( a=0; a< out_nseq; a++)
 	    for ( b=0; b< out_nseq; b++)
-	      d[a][b]=distances[a][b];
-	  
+	      {
+		d[a][b]=distances[a][b];
+	      }
 	  T=dist2nj_tree ( d, out_seq_name, out_nseq, tree_file);
 	  
 	  free_double (d, -1);
@@ -1158,7 +1204,7 @@ Alignment * upgma_merge_aln_rows (Alignment *A, int *ns, int **ls,int N, int**ma
 	mat[best_a][a]=mat[a][best_a]=upgma_pair_wise (A, ls[best_a], ns[best_a], ls[a], ns[a], CL);
     }
   
-  HERE ("DONE");
+  
   
   n[0]--;
   return A;
@@ -1199,7 +1245,408 @@ int upgma_pair_wise (Alignment *A, int *ls0, int ns0, int *ls1, int ns1, Constra
   
   return sub_aln2ecl_raw_score (A,CL,n, fl);
 }
+//////////////////////////////////////////////////////////////////////////////
+//
+//                              km
+///////////////////////////////////////////////////////////////////////////////
+static int count;
+static Sequence *KS;
+static Alignment *KA;
+NT_node expand_km_node (NT_node T,int n, char **name, int dim, double **V);
+
+
   
+    
+
+double **aln2km_vector (Alignment *A, char *mode, int *dim)
+{
+  double **v;
+  int a,b,c;
+  int mdim;
+  int use_len=0;
+  Sequence *S;
+  S=aln2seq(A);
+  
+  if ( strstr (mode, "diaa"))
+    {
+      
+      mdim=26*26;
+      v=declare_double (A->nseq,mdim+4);
+      for (a=0; a<A->nseq; a++)v[a]=seq2diaa(S->seq[a], v[a]);
+      use_len=1;
+    }
+  else if ( strstr (mode, "triaa"))
+    {
+      mdim=26*26*26;
+      v=declare_double (A->nseq,mdim+4);
+      for (a=0; a<A->nseq; a++) v[a]=seq2triaa(S->seq[a], v[a]);
+      use_len=1;
+    }
+  else if ( strstr (mode, "tetraa"))
+    {
+      mdim=26*26*26*26;
+      v=declare_double (A->nseq,mdim+4);
+      for (a=0; a<A->nseq; a++) v[a]=seq2tetraa(S->seq[a], v[a]);
+      use_len=1;
+    }
+  
+  else if (strstr (mode, "msar"))
+    {
+      int start=rand()%(A->len_aln-110);
+      int end=start+100;
+      
+      mdim=end-start+1;
+      v=declare_double (A->nseq, mdim+4);
+      
+      for (a=0; a<A->nseq; a++)
+	{
+	  for (b=0,c=start; c<end;b++,c++)
+	    {
+	      v[a][b]=(A->seq_al[a][c]=='-')?1:0;
+	    }
+	}
+    }
+  else if (strstr (mode, "msa1"))
+    {
+      int window=10;
+      
+      mdim=A->len_aln;
+      v=declare_double (A->nseq, mdim+4);
+      
+      for (a=0; a<A->nseq; a++)
+	{
+	  for (b=0; b<A->len_aln;b++)
+	    {
+	      v[a][b]=(A->seq_al[a][b]=='-')?1:0;
+	    }
+	}
+    }
+   else if (strstr (mode, "msa2"))
+    {
+      int window=10;
+      
+      mdim=A->len_aln;
+      v=declare_double (A->nseq, mdim+4);
+      
+      for (a=0; a<A->nseq; a++)
+	{
+	  for (b=0; b<A->len_aln;b++)
+	    {
+	      v[a][b]=A->seq_al[a][b];
+	    }
+	}
+    }
+   else if (strstr (mode, "msa3"))
+    {
+      int window=10;
+      
+      mdim=A->len_aln;
+      v=declare_double (A->nseq, mdim+4);
+      
+      for (a=0; a<A->nseq; a++)
+	{
+	  
+	  for (b=0; b<A->len_aln-window;b++)
+	    {
+	      for (c=0; c<window; c++)
+		v[a][b]+=(A->seq_al[a][b]=='-')?1:0;
+	    }
+	}
+    }
+  else if (strstr (mode, "msa4"))
+    {
+      mdim=A->len_aln;
+      v=declare_double (A->nseq, mdim+4);
+      
+      for (a=0; a<A->nseq; a++)
+	{
+	  
+	  for (b=0; b<A->len_aln;b++)
+	    {
+	      if (A->seq_al[a][b]=='-')c++;
+	      else {v[a][b]=c;c=0;}
+	    }
+	}
+    }
+  else
+    {
+      return aln2km_vector(A,"triaa", dim);
+    }
+  //Keep only the components with a high variance
+ 
+  if ((!dim[0] || dim[0]>=mdim))
+    {
+      dim[0]=mdim;
+      if (dim[0]<1)fprintf ( stderr, "\n\t-- 1-Keep %d components out of %d [mode=%s]\n", dim[0], mdim, mode);
+    }
+  else
+    {
+      double **v2, tsd1,tsd2;
+      double  **sd;
+      sd=declare_double    (mdim,2);
+      tsd1=tsd2=0;
+      
+      for (a=0; a<mdim; a++)
+	{
+	  double sum, sum2;
+	  double avg, diff;
+	  sum=sum2=0;
+	  
+	  for (b=0; b<A->nseq; b++)
+	    {
+	      sum+=v[b][a];
+	      sum2+=v[b][a]*v[b][a];
+	    }
+	  
+	  avg=(A->nseq==0)?0:sum/A->nseq;
+	  sd[a][0]=a;
+	  diff=(sum2/A->nseq)-(avg*avg);
+	  
+	  sd[a][1]=(diff<=0)?0:sqrt (diff);
+	  
+	  tsd1+=sd[a][1];
+	}
+     
+      if (dim[0]<=100)
+	{
+	  tsd1=(tsd1*(double)dim[0])/(double)100;
+	  dim[0]=0;
+	  sort_double_inv (sd,2,1, 0,mdim-1);
+	 
+	  for (a=0; a<mdim; a++)
+	    {
+	      tsd2+=(double)sd[a][1];
+	      if (tsd2<=tsd1){dim[0]++;}
+	      else a=mdim;
+	    }
+	  
+	  if (dim[0]<1)fprintf ( stderr, "\n\t-- 2-Keep %d components out of %d [mode=%s]\n", dim[0], mdim, mode);
+	  v2=declare_double (A->nseq, dim[0]+4);
+	  for (a=0; a<A->nseq; a++)
+	    for (b=0; b<dim[0]; b++)
+	      v2[a][b]=v[a][(int)sd[b][0]];
+	  free_double (v, -1);
+	  
+	  v=v2;
+	}
+      else
+	{
+	  if (dim[0]<1)fprintf ( stderr, "\n\t-- 3-Keep %d components out of %d [mode=%s]\n", dim[0], mdim, mode);
+	}
+    }
+  
+  //Add the len component and scale it so that it is comparable to the other components
+  if (use_len)
+    {
+      double SumL, SumV;
+      
+      SumL=SumV=0;
+      
+      for (c=0,a=0; a<A->nseq; a++)
+	{
+	  for (b=0; b<dim[0]; b++, c++)
+	    SumV+=v[a][b];
+	  v[a][dim[0]]=strlen(S->seq[a]);
+	  SumL+= v[a][dim[0]];
+	}
+      SumL/=A->nseq;
+      SumV/=c;
+      
+      for (a=0; a<A->nseq; a++)
+	{
+	  v[a][dim[0]]*=SumV/SumL;
+	}
+      dim[0]++;
+    }
+  
+  for (a=0; a<A->nseq; a++)
+    v[a][dim[0]+2]=a;
+  
+  return v;
+}
+
+NT_node ** seq2co_tree (Sequence *S, char *tree)
+{
+  static char *seq;
+  int tot_node;
+  fprintf ( stderr, "\n-----Compute ClustalOmega Tree: [Start---");
+  if (!tree)tree=vtmpnam (NULL);
+  if (!seq)seq=vtmpnam (NULL);
+  output_fasta_simple (seq, S);
+  printf_system ("clustalo --in %s --guidetree-out %s --force>/dev/null 2>/dev/null", seq,tree);
+  fprintf ( stderr, "Done]");
+  return read_tree (tree, &tot_node, S->nseq, S->name);
+}
+
+static float tid;
+static float tpairs;
+static int tprint;
+static int km_node;
+static float km_tbootstrap;
+static float km_tnode;
+
+NT_node ** seq2km_tree (Sequence *S, char *file)
+{
+  int tot_node;
+  NT_node T;
+
+  Alignment *A;
+  A=seq2aln(S,NULL,RM_GAP);
+  T=aln2km_tree (A, "triaa", 1);
+  free_aln (A);
+  if (!file)file=vtmpnam (NULL);
+  vfclose (print_tree (T, "newick", vfopen (file, "w")));
+  
+  
+  return read_tree (file, &tot_node, S->nseq, S->name);
+}
+  
+NT_node    aln2km_tree (Alignment *A, char *mode, int nboot)
+{
+  NT_node T;
+  double **V;
+  Sequence *S;
+  int dim=100;//Keep all the vector components summing up to x% of the cumulated sd
+  
+  KA=A;
+  S=KS=aln2seq(A);
+  
+  if (!nboot)nboot=1;
+  fprintf ( stderr, "\n-- Compute vectors\n");
+  V=aln2km_vector (A, mode, &dim);
+  fprintf ( stderr, "\n-- Estimate Tree (%d boostrap replicates)\n", nboot);
+  T=rec_km_tree (A->name,A->nseq,dim,V, nboot);
+  
+  if (tprint){fprintf ( stderr, "\n---NPAIRS: %d avg id: %.2f %%\n", (int)tpairs, tid/tpairs);}
+  
+  if (nboot>1)fprintf (stderr, "\n-- %5d tested Nodes -- Average bootstrap: %.2f -- %d Replicates\n", (int)km_tnode, km_tbootstrap/km_tnode, nboot);
+  
+  return T;
+}
+NT_node rec_km_tree (char **name,int n,int dim,double **V, int nboot)
+{
+  NT_node T;
+  Alignment *A;
+  
+  T=new_declare_tree_node ();
+  if (n==1)
+    {
+      
+      T->dist=1;
+      sprintf (T->name, "%s", name[(int)V[0][dim+2]]);
+      T->isseq=1;
+    }
+  else if (n==2)
+    {
+      NT_node T0,T1;
+     
+            
+      T0=T->left=new_declare_tree_node ();
+      T1=T->right=new_declare_tree_node ();
+      
+      T0->parent=T1->parent=T;
+      T->dist=T0->dist=T1->dist=1;
+          
+      sprintf (T0->name, "%s", name[(int)V[0][dim+2]]);
+      sprintf (T1->name, "%s", name[(int)V[1][dim+2]]);
+  
+      T0->isseq=1;
+      T1->isseq=1;
+      if (tprint)
+	{
+	  Alignment *A;
+	  int id;
+	  A=align_two_sequences (KS->seq[(int)V[0][dim+2]],KS->seq[(int)V[1][dim+2]],"pam250mt",-10,-2, "myers_miller_pair_wise");
+	  id=aln2sim(A, "idmat");
+	  tid+=id;
+	  tpairs++;
+	  fprintf ( stderr, "\nID=%4d L=%5d (%d)", id, A->len_aln,(int)tpairs);
+	  free_aln (A);
+	}
+    }
+  else
+    {
+      double  **V0, **V1;
+      int n0,n1,a;
+      int d;
+      km_node++;
+      
+      T->bootstrap=(int)km_kmeans_bs (V,n,dim,2,0.001,NULL,nboot);
+      
+      T->dist=1;
+      for (n0=n1=a=0; a<n; a++)(V[a][dim+1]==0)?n0++:n1++;
+      fprintf ( stderr, "\t--Resolve Node %5d: (%5d .. %5d) -- %5d Support: %3d\n", km_node, n0, n1,MIN(n1,n0), (int)T->bootstrap);
+      km_tbootstrap+=T->bootstrap;
+      if (nboot==1)T->bootstrap=0;
+      km_tnode++;
+      
+      V0=vcalloc (n0, sizeof (double **));
+      V1=vcalloc (n1, sizeof (double **));
+      for (n0=n1=a=0; a<n; a++)
+	{
+	  if  (V[a][dim+1]==0)V0[n0++]=V[a];
+	  else V1[n1++]=V[a];
+	}
+      if      (n0==0 ){expand_km_node(T,n1,name, dim,V1);}
+      else if (n1==0 ){expand_km_node(T,n0,name, dim,V0);}
+      else 
+	{
+	  T->left =rec_km_tree (name, n0,dim,V0,nboot);
+	  T->right=rec_km_tree (name, n1,dim,V1,nboot);
+	  (T->left)->parent=(T->right)->parent=T;
+	}
+      vfree(V0);
+      vfree(V1);
+    }
+  return T;
+}
+
+NT_node expand_km_node(NT_node T,int n, char ** name, int dim, double **V)
+{
+  NT_node Root,L, R;
+  int a,b;
+  
+  Root=T;
+   
+  fprintf ( stderr, "\t**Expand  Node %5d into %5d nodes\n", km_node, n);
+  km_node+=n;
+  
+		
+  for (a=0; a<n-1; a++)
+    {
+      L=T->left=new_declare_tree_node ();
+      L->parent=T;
+      L->isseq=1;
+      L->dist=0;
+      sprintf (L->name, "%s", name[(int)V[a][dim+2]]);
+      
+      R=T->right=new_declare_tree_node ();
+      R->parent=T;
+      R->dist=0;
+      
+      T=R;
+    }
+  T->isseq=1;
+  sprintf (T->name, "%s", name[(int)V[n-1][dim+2]]);
+  return Root;
+}
+/*
+void km_print_tree(T)
+{
+  if (!T->isseq)
+    {
+      fprintf (stdout, "(");
+      km_print_tree (T->left);
+      km_print_tree (T->right);
+      fprintf (stdout, ")");
+    }
+  else
+    {
+      fprintf (stdout, "%s ", T->name);
+    }
+  return T;
+}
+*/
 //////////////////////////////////////////////////////////////////////////////
 //
 //                              UPGMA
@@ -1445,7 +1892,7 @@ float get_split_dist ( Alignment *A, NT_node L, NT_node R, Split **S)
 /* Centro de Regulacio Genomica */
 /*and */
 /*Cedric Notredame */
-/*Fri Feb 18 08:27:45 CET 2011 - Revision 596. */
+/*2012-02-16 18:52:59. */
 /*All rights reserved.*/
 /*This file is part of T-COFFEE.*/
 /**/
